==> algoliasearch-client-kotlin-2.1.1-sources.jar: commonTest/model/filter/TestFilterFacetString.kt <==
package model.filter

import attributeA
import com.algolia.search.model.filter.Filter
import com.algolia.search.model.filter.FilterConverter
import shouldEqual
import kotlin.test.Test

internal class TestFilterFacetString {

    private val filter = Filter.Facet(attributeA, "valueA")
    private val filterNegate = !Filter.Facet(attributeA, "valueA")
    private val filterSpace = Filter.Facet(attributeA, "value with space")
    private val filterScore = Filter.Facet(attributeA, "valueA", 1)

    @Test
    fun sql() {
        FilterConverter.SQL(filter) shouldEqual "\"attributeA\":\"valueA\""
        FilterConverter.SQL(filterNegate) shouldEqual "NOT \"attributeA\":\"valueA\""
        FilterConverter.SQL(filterSpace) shouldEqual "\"attributeA\":\"value with space\""
        FilterConverter.SQL(filterScore) shouldEqual "\"attributeA\":\"valueA\"<score=1>"
    }

    @Test
    fun legacy() {
        FilterConverter.Legacy(filter) shouldEqual listOf("\"attributeA\":\"valueA\"")
        FilterConverter.Legacy(filterNegate) shouldEqual listOf("\"attributeA\":-\"valueA\"")
        FilterConverter.Legacy(filterSpace) shouldEqual listOf("\"attributeA\":\"value with space\"")
        FilterConverter.Legacy(filterScore) shouldEqual listOf("\"attributeA\":\"valueA\"<score=1>")
    }

    @Test
    fun legacyUnquoted() {
        FilterConverter.Legacy.Unquoted(filter) shouldEqual listOf("attributeA:valueA")
        FilterConverter.Legacy.Unquoted(filterNegate) shouldEqual listOf("attributeA:-valueA")
        FilterConverter.Legacy.Unquoted(filterSpace) shouldEqual listOf("attributeA:value with space")
        FilterConverter.Legacy.Unquoted(filterScore) shouldEqual listOf("attributeA:valueA<score=1>")
    }
}

==> algoliasearch-client-kotlin-2.1.4-sources.jar: commonTest/model/filter/TestFilterFacetString.kt <==
package model.filter

import attributeA
import com.algolia.search.model.filter.Filter
import com.algolia.search.model.filter.FilterConverter
import shouldEqual
import kotlin.test.Test

internal class TestFilterFacetString {

    private val filter = Filter.Facet(attributeA, "valueA")
    private val filterNegate = !Filter.Facet(attributeA, "valueA")
    private val filterSpace = Filter.Facet(attributeA, "value with space")
    private val filterScore = Filter.Facet(attributeA, "valueA", 1)
    private val filterQuotation = Filter.Facet(attributeA, "45\"-50\" tv\'s")

    @Test
    fun sql() {
        FilterConverter.SQL(filter) shouldEqual "\"attributeA\":\"valueA\""
        FilterConverter.SQL(filterNegate) shouldEqual "NOT \"attributeA\":\"valueA\""
        FilterConverter.SQL(filterSpace) shouldEqual "\"attributeA\":\"value with space\""
        FilterConverter.SQL(filterScore) shouldEqual "\"attributeA\":\"valueA\"<score=1>"
        FilterConverter.SQL(filterQuotation) shouldEqual "\"attributeA\":\"45\\\"-50\\\" tv's\""
    }

    @Test
    fun legacy() {
        FilterConverter.Legacy(filter) shouldEqual listOf("\"attributeA\":\"valueA\"")
        FilterConverter.Legacy(filterNegate) shouldEqual listOf("\"attributeA\":-\"valueA\"")
        FilterConverter.Legacy(filterSpace) shouldEqual listOf("\"attributeA\":\"value with space\"")
        FilterConverter.Legacy(filterScore) shouldEqual listOf("\"attributeA\":\"valueA\"<score=1>")
        FilterConverter.Legacy(filterQuotation) shouldEqual listOf("\"attributeA\":\"45\\\"-50\\\" tv's\"")
    }

    @Test
    fun legacyUnquoted() {
        FilterConverter.Legacy.Unquoted(filter) shouldEqual listOf("attributeA:valueA")
        FilterConverter.Legacy.Unquoted(filterNegate) shouldEqual listOf("attributeA:-valueA")
        FilterConverter.Legacy.Unquoted(filterSpace) shouldEqual listOf("attributeA:value with space")
        FilterConverter.Legacy.Unquoted(filterScore) shouldEqual listOf("attributeA:valueA<score=1>")
        FilterConverter.Legacy.Unquoted(filterQuotation) shouldEqual listOf("attributeA:45\\\"-50\\\" tv's")
    }
}
